@@ -579,20 +579,31 @@ def _to_datetime(conn, rs, col):
     java_val = rs.getTimestamp(col)
     if not java_val:
         return
-    d = datetime.datetime.strptime(str(java_val)[:19], "%Y-%m-%d %H:%M:%S")
-    d = d.replace(microsecond=int(str(java_val.getNanos())[:6]))
+    try:
+        d = datetime.datetime.strptime(str(java_val)[:19], "%Y-%m-%d %H:%M:%S")
+        d = d.replace(microsecond=int(str(java_val.getNanos())[:6]))
+    except ValueError as ve:
+        d = str(java_val)
     return str(d)
 
 
 def _to_time(conn, rs, col):
-    java_val = rs.getTime(col)
+    try:
+        java_val = rs.getTime(col)
+    except Exception:
+        # 处理一些超过Python数据类型限制的时间类型
+        return rs.getString(col)
     if not java_val:
         return
     return str(java_val)
 
 
 def _to_date(conn, rs, col):
-    java_val = rs.getDate(col)
+    try:
+        java_val = rs.getDate(col)
+    except Exception:
+        # 处理一些超过Python数据类型限制的时间类型
+        return rs.getString(col)
     if not java_val:
         return
     # The following code requires Python 3.3+ on dates before year 1900.
@@ -602,6 +613,18 @@ def _to_date(conn, rs, col):
     # https://github.com/baztian/jaydebeapi/issues/18):
     return str(java_val)[:10]
 
+def _to_bit(conn, rs, col):
+    java_val = rs.getObject(col)
+    if java_val is None:
+        return
+    m_TypeName = str(java_val.getClass().getTypeName())
+    if m_TypeName == "byte[]":
+        m_BitAsciiStr = "0b" + str(bin(int.from_bytes(java_val, sys.byteorder))).lstrip("0b").zfill(len(java_val)*8)
+        return m_BitAsciiStr
+    else:
+        # return binascii.b2a_hex(java_val.getBytes(0, 1024))
+        raise SQLCliException("SQLCLI-00000: Unknown java class type [" + m_TypeName + "] in _to_bit")
+
 
 def _to_binary(conn, rs, col):
     java_val = rs.getObject(col)
@@ -618,6 +641,11 @@ def _to_binary(conn, rs, col):
             return ""
     elif m_TypeName.find("BFILE") != -1:
         return "bfilename(" + java_val.getDirAlias() + ":" + java_val.getName() + ")"
+    elif m_TypeName.find("Boolean") != -1:
+        if java_val == 0:
+            return "False"
+        else:
+            return "True"
     else:
         # return binascii.b2a_hex(java_val.getBytes(0, 1024))
         raise SQLCliException("SQLCLI-00000: Unknown java class type [" + m_TypeName + "] in _to_binary")
@@ -628,14 +656,8 @@ def _java_to_py(java_method):
         java_val = rs.getObject(col)
         if java_val is None:
             return
-        if isinstance(java_val, int):
-            return int(java_val)
-        elif isinstance(java_val, string_type):
-            return str(java_val)
-        elif isinstance(java_val, bool):
-            return bool(java_val)
-        elif isinstance(java_val, float):
-            return float(java_val)
+        if isinstance(java_val, (string_type, int, float, bool)):
+            return java_val
         return getattr(java_val, java_method)()
     return to_py
 
@@ -651,6 +673,10 @@ def _java_to_py_bigdecimal(conn, rs, col):
         return decimal.Decimal(java_val.toString())
     elif m_TypeName == "java.math.BigInteger":
         return decimal.Decimal(java_val.toString())
+    elif m_TypeName == "java.lang.Double":
+        return decimal.Decimal(java_val.toString())
+    elif m_TypeName == "java.lang.Float":
+        return decimal.Decimal(java_val.toString())
     else:
         raise SQLCliException(
             "SQLCLI-00000: Unknown java class type [" + m_TypeName + "] in _java_to_py_bigdecimal")
@@ -853,16 +879,15 @@ _DEFAULT_CONVERTERS = {
     'BFILE':                        _to_binary,
     'DECIMAL':                      _java_to_py_bigdecimal,
     'NUMERIC':                      _java_to_py_bigdecimal,
-    'DOUBLE':                       _java_to_py('doubleValue'),
+    'DOUBLE':                       _java_to_py_bigdecimal,
     'FLOAT':                        _java_to_py('doubleValue'),
-    'REAL':                         _java_to_py('doubleValue'),
+    'REAL':                         _java_to_py_bigdecimal,
     'TINYINT':                      _java_to_py('intValue'),
     'INTEGER':                      _java_to_py('intValue'),
     'SMALLINT':                     _java_to_py('intValue'),
     'BIGINT':                       _java_to_py_bigdecimal,
     'BOOLEAN':                      _java_to_py('booleanValue'),
-    'BIT':                          _java_to_py('booleanValue'),
+    'BIT':                          _to_bit,
     'STRUCT':                       _java_to_py_stru,
     'ARRAY':                        _java_to_py_array
 }
-
